summaryrefslogtreecommitdiff
path: root/nuttx/graphics/nxsu/nx_constructwindow.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/graphics/nxsu/nx_constructwindow.c')
-rw-r--r--nuttx/graphics/nxsu/nx_constructwindow.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/graphics/nxsu/nx_constructwindow.c b/nuttx/graphics/nxsu/nx_constructwindow.c
index b77025dcf..0703ab644 100644
--- a/nuttx/graphics/nxsu/nx_constructwindow.c
+++ b/nuttx/graphics/nxsu/nx_constructwindow.c
@@ -83,14 +83,14 @@
* inheritance: The caller's window structure may include extensions that
* are not visible to NX.
*
* NOTE: wnd must have been allocated using kmalloc() (or related allocators)
* Once provided to nx_constructwindow() that memory is owned and managed
* by NX. On certain error conditions or when the window is closed, NX will
* free the window.
*
* Input Parameters:
* handle - The handle returned by nx_connect
* wnd - The pre-allocated window structure.
* cb - Callbacks used to process window events
* arg - User provided value that will be returned with NX callbacks.
*
@@ -100,16 +100,17 @@
*
****************************************************************************/
-int nx_constructwindow(NXHANDLE handle, FAR struct nxbe_window_s *wnd,
+int nx_constructwindow(NXHANDLE handle, NXWINDOW wnd,
FAR const struct nx_callback_s *cb, FAR void *arg)
{
FAR struct nxfe_state_s *fe = (FAR struct nxfe_state_s *)handle;
+ FAR struct nxbe_window_s *wnd = (FAR struct nxbe_window_s *)hwnd;
FAR struct nxbe_state_s *be = &fe->be;
#ifdef CONFIG_DEBUG
if (!wnd)
{
- errno = EINVAL;
+ set_errno(EINVAL);
return ERROR;
}
@@ -149,4 +150,3 @@ int nx_constructwindow(NXHANDLE handle, FAR struct nxbe_window_s *wnd,
return OK;
}
-
@@ -83,14 +83,14 @@
* are not visible to NX.
*
- * NOTE: wnd must have been allocated using kmalloc() (or related allocators)
+ * NOTE: hwnd must have been allocated using kmalloc() (or related allocators)
* Once provided to nx_constructwindow() that memory is owned and managed
* by NX. On certain error conditions or when the window is closed, NX will
@@ -83,14 +83,14 @@
* Input Parameters:
* handle - The handle returned by nx_connect
- * wnd - The pre-allocated window structure.
+ * hwnd - The pre-allocated window structure.
* cb - Callbacks used to process window events
* arg - User provided value that will be returned with NX callbacks.